aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClayton Walker <clayton.m.walker@gmail.com>2024-06-03 14:41:43 -0600
committerGitHub <noreply@github.com>2024-06-03 16:41:43 -0400
commit5d09e84bfd787211b85fb09111efbf2d367cfd2e (patch)
treefd7a3d0a3b14efd5bfa6046c856cd3068aadabf0
parentc90794f83170d770eb247c56ade80c0a6661a5d6 (diff)
downloadokio-upstream-master.tar.gz
Upgrade bnd (#1487)upstream-master
-rw-r--r--build.gradle.kts4
-rw-r--r--gradle/libs.versions.toml2
-rw-r--r--okio-fakefilesystem/build.gradle.kts7
-rw-r--r--okio/build.gradle.kts13
4 files changed, 14 insertions, 12 deletions
diff --git a/build.gradle.kts b/build.gradle.kts
index c9490faa..e47e844f 100644
--- a/build.gradle.kts
+++ b/build.gradle.kts
@@ -1,4 +1,4 @@
-import aQute.bnd.gradle.BundleTaskConvention
+import aQute.bnd.gradle.BundleTaskExtension
import com.diffplug.gradle.spotless.SpotlessExtension
import com.vanniktech.maven.publish.MavenPublishBaseExtension
import com.vanniktech.maven.publish.SonatypeHost
@@ -46,7 +46,7 @@ apply(plugin = "com.vanniktech.maven.publish.base")
// When scripts are applied the buildscript classes are not accessible directly therefore we save
// the class here to make it accessible.
-ext.set("bndBundleTaskConventionClass", BundleTaskConvention::class.java)
+ext.set("bndBundleTaskExtensionClass", BundleTaskExtension::class.java)
allprojects {
group = project.property("GROUP") as String
diff --git a/gradle/libs.versions.toml b/gradle/libs.versions.toml
index 86f8a717..8f4d08ca 100644
--- a/gradle/libs.versions.toml
+++ b/gradle/libs.versions.toml
@@ -16,7 +16,7 @@ jmh-core = { module = "org.openjdk.jmh:jmh-core", version.ref = "jmh" }
jmh-generator = { module = "org.openjdk.jmh:jmh-generator-annprocess", version.ref = "jmh" }
dokka = { module = "org.jetbrains.dokka:dokka-gradle-plugin", version = "1.9.20" }
spotless = { module = "com.diffplug.spotless:spotless-plugin-gradle", version = "6.25.0" }
-bnd = { module = "biz.aQute.bnd:biz.aQute.bnd.gradle", version = "6.4.0" }
+bnd = { module = "biz.aQute.bnd:biz.aQute.bnd.gradle", version = "7.0.0" }
vanniktech-publish-plugin = { module = "com.vanniktech:gradle-maven-publish-plugin", version = "0.27.0" }
test-junit = { module = "junit:junit", version = "4.13.2" }
test-assertj = { module = "org.assertj:assertj-core", version = "3.25.3" }
diff --git a/okio-fakefilesystem/build.gradle.kts b/okio-fakefilesystem/build.gradle.kts
index afebff16..e1816f86 100644
--- a/okio-fakefilesystem/build.gradle.kts
+++ b/okio-fakefilesystem/build.gradle.kts
@@ -57,8 +57,8 @@ tasks {
val jvmJar by getting(Jar::class) {
// BundleTaskConvention() crashes unless there's a 'main' source set.
sourceSets.create(SourceSet.MAIN_SOURCE_SET_NAME)
- val bndConvention = aQute.bnd.gradle.BundleTaskConvention(this)
- bndConvention.setBnd(
+ val bndExtension = aQute.bnd.gradle.BundleTaskExtension(this)
+ bndExtension.setBnd(
"""
Export-Package: okio.fakefilesystem
Automatic-Module-Name: okio.fakefilesystem
@@ -67,7 +67,8 @@ tasks {
)
// Call the convention when the task has finished to modify the jar to contain OSGi metadata.
doLast {
- bndConvention.buildBundle()
+ bndExtension.buildAction()
+ .execute(this)
}
}
}
diff --git a/okio/build.gradle.kts b/okio/build.gradle.kts
index eea0f821..901b38f1 100644
--- a/okio/build.gradle.kts
+++ b/okio/build.gradle.kts
@@ -1,4 +1,4 @@
-import aQute.bnd.gradle.BundleTaskConvention
+import aQute.bnd.gradle.BundleTaskExtension
import com.vanniktech.maven.publish.JavadocJar.Dokka
import com.vanniktech.maven.publish.KotlinMultiplatform
import com.vanniktech.maven.publish.MavenPublishBaseExtension
@@ -190,19 +190,20 @@ kotlin {
tasks {
val jvmJar by getting(Jar::class) {
// BundleTaskConvention() crashes unless there's a 'main' source set.
sourceSets.create(SourceSet.MAIN_SOURCE_SET_NAME)
- val bndConvention = BundleTaskConvention(this)
- bndConvention.setBnd(
+ val bndExtension = BundleTaskExtension(this)
+ bndExtension.setBnd(
"""
Export-Package: okio
Automatic-Module-Name: okio
Bundle-SymbolicName: com.squareup.okio
""",
)
// Call the convention when the task has finished to modify the jar to contain OSGi metadata.
doLast {
- bndConvention.buildBundle()
+ bndExtension.buildAction()
+ .execute(this)
}
}
}
@@ -190,19 +190,20 @@ kotlin {
tasks {
val jvmJar by getting(Jar::class) {
- // BundleTaskConvention() crashes unless there's a 'main' source set.
+ // BundleTaskExtension() crashes unless there's a 'main' source set.
sourceSets.create(SourceSet.MAIN_SOURCE_SET_NAME)
@@ -190,19 +190,20 @@ kotlin {
""",
)
- // Call the convention when the task has finished to modify the jar to contain OSGi metadata.
+ // Call the extension when the task has finished to modify the jar to contain OSGi metadata.
doLast {